==> tutility-3.1.0.tgz: package/README.md <==
# Utils

[![Build Status](https://semaphoreci.com/api/v1/nimjetushar/utils/branches/master/shields_badge.svg)](https://semaphoreci.com/nimjetushar/utils)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/86a61b646ab041c0b64e502b3d8be7a7)](https://www.codacy.com/app/tushar/Utils?utm_source=github.com&utm_medium=referral&utm_content=nimjetushar/Utils&utm_campaign=Badge_Grade)
[![Codacy Badge](https://api.codacy.com/project/badge/Coverage/86a61b646ab041c0b64e502b3d8be7a7)](https://www.codacy.com/app/tushar/Utils?utm_source=github.com&utm_medium=referral&utm_content=nimjetushar/Utils&utm_campaign=Badge_Coverage)
[![Dependabot Status](https://api.dependabot.com/badges/status?host=github&repo=nimjetushar/Utils)](https://dependabot.com)
</br>
![GitHub pull requests](https://img.shields.io/github/issues-pr/nimjetushar/Utils.svg)

## This utility provides basic utility functions which are mainly used in day to day coding and not ment perform various utility operations which are handled by other utility lib.

## Getting started:

`npm i tutility --save`

Import the js and start working. <br>
When working with IE or older browser version which does not support es6 syntax then library needs to be included in compilation to get it compied to es5 to make it work or use file for dist. 

## [Documentation](https://nimjetushar.github.io/Utils/):

## Testing

Use index.html from sample for testing the utility into the console.

## Dependencies

[![devDependencies Status](https://david-dm.org/nimjetushar/utils/dev-status.svg)](https://david-dm.org/nimjetushar/utils?type=dev)

## Licence

[![GitHub license](https://img.shields.io/github/license/nimjetushar/Utils.svg?style=popout)](https://github.com/nimjetushar/Utils/blob/master/LICENSE)

==> tutility-4.2.0.tgz: package/README.md <==
# Utils

[![Build Status](https://semaphoreci.com/api/v1/nimjetushar/utils/branches/master/shields_badge.svg)](https://semaphoreci.com/nimjetushar/utils)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/86a61b646ab041c0b64e502b3d8be7a7)](https://www.codacy.com/app/tushar/Utils?utm_source=github.com&utm_medium=referral&utm_content=nimjetushar/Utils&utm_campaign=Badge_Grade)
[![Codacy Badge](https://api.codacy.com/project/badge/Coverage/86a61b646ab041c0b64e502b3d8be7a7)](https://www.codacy.com/app/tushar/Utils?utm_source=github.com&utm_medium=referral&utm_content=nimjetushar/Utils&utm_campaign=Badge_Coverage)
[![Dependabot Status](https://api.dependabot.com/badges/status?host=github&repo=nimjetushar/Utils)](https://dependabot.com)
</br>
![npm](https://img.shields.io/npm/v/tutility)
![GitHub pull requests](https://img.shields.io/github/issues-pr/nimjetushar/Utils.svg)

## This utility provides basic utility functions which are mainly used in day to day coding and not ment perform various utility operations which are handled by other utility lib.

## Getting started:

`npm i tutility --save`

Import the js as required </br>
`import { deepCopy, isEqual, ... } 'tutility'` for utilities </br>
`import Detect 'tutility'` for browser detect utility </br>
`import Logger 'tutility'` for logger </br>

## [Documentation](https://nimjetushar.github.io/Utils/)
[Here](https://nimjetushar.github.io/Utils/) you can find api documentation

## Licence
[![GitHub license](https://img.shields.io/github/license/nimjetushar/Utils.svg?style=popout)](https://github.com/nimjetushar/Utils/blob/master/LICENSE)
